==> va416xx-0.1.0.crate: va416xx-0.1.0/src/dma/alt_ctrl_base_ptr.rs <==
#[doc = "Register `ALT_CTRL_BASE_PTR` reader"]
pub struct R(crate::R<ALT_CTRL_BASE_PTR_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<ALT_CTRL_BASE_PTR_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl From<crate::R<ALT_CTRL_BASE_PTR_SPEC>> for R {
    #[inline(always)]
    fn from(reader: crate::R<ALT_CTRL_BASE_PTR_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Register `ALT_CTRL_BASE_PTR` writer"]
pub struct W(crate::W<ALT_CTRL_BASE_PTR_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<ALT_CTRL_BASE_PTR_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl From<crate::W<ALT_CTRL_BASE_PTR_SPEC>> for W {
    #[inline(always)]
    fn from(writer: crate::W<ALT_CTRL_BASE_PTR_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `ALT_CTRL_BASE_PTR` reader - Base Pointer for Alternate DMA Control Register"]
pub struct ALT_CTRL_BASE_PTR_R(crate::FieldReader<u32, u32>);
impl ALT_CTRL_BASE_PTR_R {
    #[inline(always)]
    pub(crate) fn new(bits: u32) -> Self {
        ALT_CTRL_BASE_PTR_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for ALT_CTRL_BASE_PTR_R {
    type Target = crate::FieldReader<u32, u32>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `ALT_CTRL_BASE_PTR` writer - Base Pointer for Alternate DMA Control Register"]
pub struct ALT_CTRL_BASE_PTR_W<'a> {
    w: &'a mut W,
}
impl<'a> ALT_CTRL_BASE_PTR_W<'a> {
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub unsafe fn bits(self, value: u32) -> &'a mut W {
        self.w.bits = (self.w.bits & !0xffff_ffff) | (value as u32 & 0xffff_ffff);
        self.w
    }
}
impl R {
    #[doc = "Bits 0:31 - Base Pointer for Alternate DMA Control Register"]
    #[inline(always)]
    pub fn alt_ctrl_base_ptr(&self) -> ALT_CTRL_BASE_PTR_R {
        ALT_CTRL_BASE_PTR_R::new((self.bits & 0xffff_ffff) as u32)
    }
}
impl W {
    #[doc = "Bits 0:31 - Base Pointer for Alternate DMA Control Register"]
    #[inline(always)]
    pub fn alt_ctrl_base_ptr(&mut self) -> ALT_CTRL_BASE_PTR_W {
        ALT_CTRL_BASE_PTR_W { w: self }
    }
    #[doc = "Writes raw bits to the register."]
    #[inline(always)]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "DMA Channel alternate control data base pointer\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [alt_ctrl_base_ptr](index.html) module"]
pub struct ALT_CTRL_BASE_PTR_SPEC;
impl crate::RegisterSpec for ALT_CTRL_BASE_PTR_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [alt_ctrl_base_ptr::R](R) reader structure"]
impl crate::Readable for ALT_CTRL_BASE_PTR_SPEC {
    type Reader = R;
}
#[doc = "`write(|w| ..)` method takes [alt_ctrl_base_ptr::W](W) writer structure"]
impl crate::Writable for ALT_CTRL_BASE_PTR_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets ALT_CTRL_BASE_PTR to value 0"]
impl crate::Resettable for ALT_CTRL_BASE_PTR_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}

==> va416xx-0.1.1.crate: va416xx-0.1.1/src/dma/alt_ctrl_base_ptr.rs <==
#[doc = "Register `ALT_CTRL_BASE_PTR` reader"]
pub struct R(crate::R<ALT_CTRL_BASE_PTR_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<ALT_CTRL_BASE_PTR_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl From<crate::R<ALT_CTRL_BASE_PTR_SPEC>> for R {
    #[inline(always)]
    fn from(reader: crate::R<ALT_CTRL_BASE_PTR_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Register `ALT_CTRL_BASE_PTR` writer"]
pub struct W(crate::W<ALT_CTRL_BASE_PTR_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<ALT_CTRL_BASE_PTR_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl From<crate::W<ALT_CTRL_BASE_PTR_SPEC>> for W {
    #[inline(always)]
    fn from(writer: crate::W<ALT_CTRL_BASE_PTR_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `ALT_CTRL_BASE_PTR` reader - Base Pointer for Alternate DMA Control Register"]
pub struct ALT_CTRL_BASE_PTR_R(crate::FieldReader<u32, u32>);
impl ALT_CTRL_BASE_PTR_R {
    #[inline(always)]
    pub(crate) fn new(bits: u32) -> Self {
        ALT_CTRL_BASE_PTR_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for ALT_CTRL_BASE_PTR_R {
    type Target = crate::FieldReader<u32, u32>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `ALT_CTRL_BASE_PTR` writer - Base Pointer for Alternate DMA Control Register"]
pub struct ALT_CTRL_BASE_PTR_W<'a> {
    w: &'a mut W,
}
impl<'a> ALT_CTRL_BASE_PTR_W<'a> {
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub unsafe fn bits(self, value: u32) -> &'a mut W {
        self.w.bits = value as u32;
        self.w
    }
}
impl R {
    #[doc = "Bits 0:31 - Base Pointer for Alternate DMA Control Register"]
    #[inline(always)]
    pub fn alt_ctrl_base_ptr(&self) -> ALT_CTRL_BASE_PTR_R {
        ALT_CTRL_BASE_PTR_R::new(self.bits as u32)
    }
}
impl W {
    #[doc = "Bits 0:31 - Base Pointer for Alternate DMA Control Register"]
    #[inline(always)]
    pub fn alt_ctrl_base_ptr(&mut self) -> ALT_CTRL_BASE_PTR_W {
        ALT_CTRL_BASE_PTR_W { w: self }
    }
    #[doc = "Writes raw bits to the register."]
    #[inline(always)]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "DMA Channel alternate control data base pointer\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [alt_ctrl_base_ptr](index.html) module"]
pub struct ALT_CTRL_BASE_PTR_SPEC;
impl crate::RegisterSpec for ALT_CTRL_BASE_PTR_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [alt_ctrl_base_ptr::R](R) reader structure"]
impl crate::Readable for ALT_CTRL_BASE_PTR_SPEC {
    type Reader = R;
}
#[doc = "`write(|w| ..)` method takes [alt_ctrl_base_ptr::W](W) writer structure"]
impl crate::Writable for ALT_CTRL_BASE_PTR_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets ALT_CTRL_BASE_PTR to value 0"]
impl crate::Resettable for ALT_CTRL_BASE_PTR_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}
